@@ -102,20 +102,40 @@ class POAVAtoms(KDTAtoms):
                     POAV.sigma_pi_angles = sigma_pi_angles
 
     def update_attrs(self):
+        """Alisas for :meth:`POAVAtoms.compute_POAVs`"""
         self.compute_POAVs()
 
     @property
     def POAV1(self):
+        """List of :class:`~sknano.core.atoms.POAVAtom` :class:`POAV1` \
+            :attr:`~sknano.core.atoms.POAVAtom.POAV1` attribute."""
         return [atom.POAV1 for atom in self if atom.POAV1 is not None]
 
     @property
     def POAV2(self):
+        """List of :class:`~sknano.core.atoms.POAVAtom` :class:`POAV2` \
+            :attr:`~sknano.core.atoms.POAVAtom.POAV2` attribute."""
         return [atom.POAV2 for atom in self if atom.POAV2 is not None]
 
     @property
     def POAVR(self):
+        """List of :class:`~sknano.core.atoms.POAVAtom` :class:`POAVR` \
+            :attr:`~sknano.core.atoms.POAVAtom.POAVR` attribute."""
         return [atom.POAVR for atom in self if atom.POAVR is not None]
 
     def get_POAV_attr(self, POAV_class, attr):
-        return [getattr(atom, POAV_class).get_POAV_attr(attr) for atom in self
+        """Return list of :class:`~sknano.core.atoms.POAVAtom` :class:`POAV1` \
+            :class:`POAV2` or :class:`POAVR` attribute.
+
+        Parameters
+        ----------
+        POAV_class : :class:`~python:str`
+        attr : :class:`~python:str`
+
+        Returns
+        -------
+        :class:`~python:list`
+
+        """
+        return [getattr(getattr(atom, POAV_class), attr) for atom in self
                 if getattr(atom, POAV_class) is not None]
