@@ -15,7 +15,9 @@ Abstract object representations for points and vectors
    :toctree: generated/
 
    Point
+   Points
    Vector
+   Vectors
 
 Linear algebra transforms
 ----------------------------
@@ -34,11 +36,14 @@ Number theory
    totient_func
 
 """
+from __future__ import absolute_import
 __docformat__ = 'restructuredtext en'
 
 from ._extras import *
 from ._point import *
+from ._points import *
 from ._vector import *
+from ._vectors import *
 from ._transforms import *
 
 __all__ = [s for s in dir() if not s.startswith('_')]
